@@ -1,6 +1,7 @@
 function Debugger(sel) {
     var dbg = this;
     var $elt = this.$elt = $(sel);
+    var perlVarPopoverDelay = 400;  // Time in ms the mouse has to rest over a variable before it gets the value
 
     this.filewindowDiv = $elt.find('div#filewindow');
     this.stackDiv = $elt.find('div#stack');
@@ -125,8 +126,8 @@ function Debugger(sel) {
                         is_string_eval: is_string_eval,
                         wantarray: frame_obj.sigil,
                         active: $tabs.children().length == 0
-                    }));
-            var $tab_link = $tab.find('a[rel="tooltip"]').tooltip();
+                    }))
+                    .tooltip();
 
             $codePane = $( this.templates.navPane({
                                 serial: frame_obj.serial,
@@ -140,7 +141,7 @@ function Debugger(sel) {
             setElementHeight.call($codePane.find('.managed-height'));
 
             var needs_args = 1;
-            $tab_link.on('click', function() {
+            $tab.find('a').on('click', function() {
                 if (needs_args) {
                     needs_args = 0;
 
@@ -301,10 +302,11 @@ function Debugger(sel) {
     };
 
     this.handleControlButtonResponse = function(response) {
-        var events = [];
+        var events = [],
+            watchedExpressionManager = this.watchedExpressionManager;
         if (response.events) {
             events = response.events.map(function(event) {
-                return new ProgramEvent(event);
+                return new ProgramEvent(event, watchedExpressionManager);
             });
         }
 
@@ -374,7 +376,7 @@ function Debugger(sel) {
         var also = $elt.attr('data-part-of');
         if (also) {
             // hilite it, too
-            $elt.parent().find('[data-eval="'+also+'"]').addClass('hovered-perl-var');
+            $elt.siblings('[data-eval="'+also+'"]').addClass('hovered-perl-var');
         }
         $perlVarPopover = $elt;
 
@@ -385,12 +387,19 @@ function Debugger(sel) {
                 restInterface.getVarAtLevel(eval, stack_level)
                              .done(function(data) { drawPerlPopover(data, $elt) });
             }
-        }, 400);
+        }, perlVarPopoverDelay);
         $perlVarPopover.data('timerid', timer);
     }
 
     function removePopoverPerlVar (e) {
-        $(e.target).removeClass('hovered-perl-var');
+        var $target = $(e.target),
+            part_of = $target.attr('data-part-of');
+
+        if (part_of !== undefined) {
+            $target = $target.add('[data-eval="'+part_of+'"]');
+        }
+
+        $target.removeClass('hovered-perl-var');
         if ($perlVarPopover) {
             $perlVarPopover.popover('destroy');
             $perlVarPopover = undefined;
@@ -666,6 +675,7 @@ function Debugger(sel) {
 
     this.breakpointManager = new BreakpointManager(this.$elt, this.restInterface);
     this.watchedExpressionManager = new WatchedExprManager(this.restInterface);
+    this.watchedExpressionManager.loadWatchpoints();
 
     this.stackManager = new StackManager(this.restInterface);
     this.stackManager.initialize()
